==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkHyperOctree.java <==
// java wrapper for vtkHyperOctree object
//

package vtk;
import vtk.*;

public class vtkHyperOctree extends vtkDataSet
{

  private native long LEVELS_0();
  public vtkInformationIntegerKey LEVELS() {
    long temp = LEVELS_0();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long DIMENSION_1();
  public vtkInformationIntegerKey DIMENSION() {
    long temp = DIMENSION_1();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long SIZES_2();
  public vtkInformationDoubleVectorKey SIZES() {
    long temp = SIZES_2();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native String GetClassName_3();
  public String GetClassName()
    { return GetClassName_3(); }

  private native int IsA_4(String id0);
  public int IsA(String id0)
    { return IsA_4(id0); }

  private native int GetDataObjectType_5();
  public int GetDataObjectType()
    { return GetDataObjectType_5(); }

  private native void CopyStructure_6(vtkDataSet id0);
  public void CopyStructure(vtkDataSet id0)
    { CopyStructure_6(id0); }

  private native int GetDimension_7();
  public int GetDimension()
    { return GetDimension_7(); }

  private native void SetDimension_8(int id0);
  public void SetDimension(int id0)
    { SetDimension_8(id0); }

  private native int GetNumberOfCells_9();
  public int GetNumberOfCells()
    { return GetNumberOfCells_9(); }

  private native int GetNumberOfLeaves_10();
  public int GetNumberOfLeaves()
    { return GetNumberOfLeaves_10(); }

  private native int GetNumberOfPoints_11();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_11(); }

  private native int GetMaxNumberOfPoints_12(int id0);
  public int GetMaxNumberOfPoints(int id0)
    { return GetMaxNumberOfPoints_12(id0); }

  private native int GetMaxNumberOfPointsOnBoundary_13(int id0);
  public int GetMaxNumberOfPointsOnBoundary(int id0)
    { return GetMaxNumberOfPointsOnBoundary_13(id0); }

  private native int GetMaxNumberOfCellsOnBoundary_14(int id0);
  public int GetMaxNumberOfCellsOnBoundary(int id0)
    { return GetMaxNumberOfCellsOnBoundary_14(id0); }

  private native int GetNumberOfLevels_15();
  public int GetNumberOfLevels()
    { return GetNumberOfLevels_15(); }

  private native void SetSize_16(double id0,double id1,double id2);
  public void SetSize(double id0,double id1,double id2)
    { SetSize_16(id0,id1,id2); }

  private native void SetSize_17(double id0[]);
  public void SetSize(double id0[])
    { SetSize_17(id0); }

  private native double[] GetSize_18();
  public double[] GetSize()
    { return GetSize_18(); }

  private native void SetOrigin_19(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_19(id0,id1,id2); }

  private native void SetOrigin_20(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_20(id0); }

  private native double[] GetOrigin_21();
  public double[] GetOrigin()
    { return GetOrigin_21(); }

  private native long NewCellCursor_22();
  public vtkHyperOctreeCursor NewCellCursor() {
    long temp = NewCellCursor_22();

    if (temp == 0) return null;
    return (vtkHyperOctreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SubdivideLeaf_23(vtkHyperOctreeCursor id0);
  public void SubdivideLeaf(vtkHyperOctreeCursor id0)
    { SubdivideLeaf_23(id0); }

  private native void CollapseTerminalNode_24(vtkHyperOctreeCursor id0);
  public void CollapseTerminalNode(vtkHyperOctreeCursor id0)
    { CollapseTerminalNode_24(id0); }

  private native double[] GetPoint_25(int id0);
  public double[] GetPoint(int id0)
    { return GetPoint_25(id0); }

  private native void GetPoint_26(int id0,double id1[]);
  public void GetPoint(int id0,double id1[])
    { GetPoint_26(id0,id1); }

  private native long GetCell_27(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_27(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetCell_28(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_28(id0,id1); }

  private native int GetCellType_29(int id0);
  public int GetCellType(int id0)
    { return GetCellType_29(id0); }

  private native void GetCellPoints_30(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_30(id0,id1); }

  private native void GetPointCells_31(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_31(id0,id1); }

  private native void GetCellNeighbors_32(int id0,vtkIdList id1,vtkIdList id2);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2)
    { GetCellNeighbors_32(id0,id1,id2); }

  private native int FindPoint_33(double id0[]);
  public int FindPoint(double id0[])
    { return FindPoint_33(id0); }

  private native void Initialize_34();
  public void Initialize()
    { Initialize_34(); }

  private native int GetMaxCellSize_35();
  public int GetMaxCellSize()
    { return GetMaxCellSize_35(); }

  private native void ShallowCopy_36(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_36(id0); }

  private native void DeepCopy_37(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_37(id0); }

  private native void GetPointsOnFace_38(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3);
  public void GetPointsOnFace(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3)
    { GetPointsOnFace_38(id0,id1,id2,id3); }

  private native void GetPointsOnParentFaces_39(int id0[],int id1,vtkHyperOctreeCursor id2,vtkHyperOctreePointsGrabber id3);
  public void GetPointsOnParentFaces(int id0[],int id1,vtkHyperOctreeCursor id2,vtkHyperOctreePointsGrabber id3)
    { GetPointsOnParentFaces_39(id0,id1,id2,id3); }

  private native void GetPointsOnEdge_40(vtkHyperOctreeCursor id0,int id1,int id2,int id3,int id4,vtkHyperOctreePointsGrabber id5);
  public void GetPointsOnEdge(vtkHyperOctreeCursor id0,int id1,int id2,int id3,int id4,vtkHyperOctreePointsGrabber id5)
    { GetPointsOnEdge_40(id0,id1,id2,id3,id4,id5); }

  private native void GetPointsOnParentEdge_41(vtkHyperOctreeCursor id0,int id1,int id2,int id3,int id4,vtkHyperOctreePointsGrabber id5);
  public void GetPointsOnParentEdge(vtkHyperOctreeCursor id0,int id1,int id2,int id3,int id4,vtkHyperOctreePointsGrabber id5)
    { GetPointsOnParentEdge_41(id0,id1,id2,id3,id4,id5); }

  private native void GetPointsOnEdge2D_42(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3);
  public void GetPointsOnEdge2D(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3)
    { GetPointsOnEdge2D_42(id0,id1,id2,id3); }

  private native void GetPointsOnParentEdge2D_43(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3);
  public void GetPointsOnParentEdge2D(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3)
    { GetPointsOnParentEdge2D_43(id0,id1,id2,id3); }

  private native long GetLeafData_44();
  public vtkDataSetAttributes GetLeafData() {
    long temp = GetLeafData_44();

    if (temp == 0) return null;
    return (vtkDataSetAttributes)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetDualGridFlag_45(int id0);
  public void SetDualGridFlag(int id0)
    { SetDualGridFlag_45(id0); }

  private native int GetDualGridFlag_46();
  public int GetDualGridFlag()
    { return GetDualGridFlag_46(); }

  private native int GetActualMemorySize_47();
  public int GetActualMemorySize()
    { return GetActualMemorySize_47(); }

  private native long GetData_48(vtkInformation id0);
  public vtkHyperOctree GetData(vtkInformation id0) {
    long temp = GetData_48(id0);

    if (temp == 0) return null;
    return (vtkHyperOctree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetData_49(vtkInformationVector id0,int id1);
  public vtkHyperOctree GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_49(id0,id1);

    if (temp == 0) return null;
    return (vtkHyperOctree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkHyperOctree() { super(); }

  public vtkHyperOctree(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkHyperOctree.java <==
// java wrapper for vtkHyperOctree object
//

package vtk;
import vtk.*;

public class vtkHyperOctree extends vtkDataSet
{

  private native long LEVELS_0();
  public vtkInformationIntegerKey LEVELS() {
    long temp = LEVELS_0();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long DIMENSION_1();
  public vtkInformationIntegerKey DIMENSION() {
    long temp = DIMENSION_1();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long SIZES_2();
  public vtkInformationDoubleVectorKey SIZES() {
    long temp = SIZES_2();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int IsTypeOf_3(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_3(id0); }

  private native int IsA_4(String id0);
  public int IsA(String id0)
    { return IsA_4(id0); }

  private native int GetDataObjectType_5();
  public int GetDataObjectType()
    { return GetDataObjectType_5(); }

  private native void CopyStructure_6(vtkDataSet id0);
  public void CopyStructure(vtkDataSet id0)
    { CopyStructure_6(id0); }

  private native int GetDimension_7();
  public int GetDimension()
    { return GetDimension_7(); }

  private native void SetDimension_8(int id0);
  public void SetDimension(int id0)
    { SetDimension_8(id0); }

  private native int GetNumberOfCells_9();
  public int GetNumberOfCells()
    { return GetNumberOfCells_9(); }

  private native int GetNumberOfLeaves_10();
  public int GetNumberOfLeaves()
    { return GetNumberOfLeaves_10(); }

  private native int GetNumberOfPoints_11();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_11(); }

  private native int GetMaxNumberOfPoints_12(int id0);
  public int GetMaxNumberOfPoints(int id0)
    { return GetMaxNumberOfPoints_12(id0); }

  private native int GetMaxNumberOfPointsOnBoundary_13(int id0);
  public int GetMaxNumberOfPointsOnBoundary(int id0)
    { return GetMaxNumberOfPointsOnBoundary_13(id0); }

  private native int GetMaxNumberOfCellsOnBoundary_14(int id0);
  public int GetMaxNumberOfCellsOnBoundary(int id0)
    { return GetMaxNumberOfCellsOnBoundary_14(id0); }

  private native int GetNumberOfLevels_15();
  public int GetNumberOfLevels()
    { return GetNumberOfLevels_15(); }

  private native void SetSize_16(double id0,double id1,double id2);
  public void SetSize(double id0,double id1,double id2)
    { SetSize_16(id0,id1,id2); }

  private native void SetSize_17(double id0[]);
  public void SetSize(double id0[])
    { SetSize_17(id0); }

  private native double[] GetSize_18();
  public double[] GetSize()
    { return GetSize_18(); }

  private native void SetOrigin_19(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_19(id0,id1,id2); }

  private native void SetOrigin_20(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_20(id0); }

  private native double[] GetOrigin_21();
  public double[] GetOrigin()
    { return GetOrigin_21(); }

  private native long NewCellCursor_22();
  public vtkHyperOctreeCursor NewCellCursor() {
    long temp = NewCellCursor_22();

    if (temp == 0) return null;
    return (vtkHyperOctreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SubdivideLeaf_23(vtkHyperOctreeCursor id0);
  public void SubdivideLeaf(vtkHyperOctreeCursor id0)
    { SubdivideLeaf_23(id0); }

  private native void CollapseTerminalNode_24(vtkHyperOctreeCursor id0);
  public void CollapseTerminalNode(vtkHyperOctreeCursor id0)
    { CollapseTerminalNode_24(id0); }

  private native double[] GetPoint_25(int id0);
  public double[] GetPoint(int id0)
    { return GetPoint_25(id0); }

  private native void GetPoint_26(int id0,double id1[]);
  public void GetPoint(int id0,double id1[])
    { GetPoint_26(id0,id1); }

  private native long GetCell_27(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_27(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCell_28(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_28(id0,id1); }

  private native int GetCellType_29(int id0);
  public int GetCellType(int id0)
    { return GetCellType_29(id0); }

  private native void GetCellPoints_30(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_30(id0,id1); }

  private native void GetPointCells_31(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_31(id0,id1); }

  private native void GetCellNeighbors_32(int id0,vtkIdList id1,vtkIdList id2);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2)
    { GetCellNeighbors_32(id0,id1,id2); }

  private native int FindPoint_33(double id0[]);
  public int FindPoint(double id0[])
    { return FindPoint_33(id0); }

  private native void Initialize_34();
  public void Initialize()
    { Initialize_34(); }

  private native int GetMaxCellSize_35();
  public int GetMaxCellSize()
    { return GetMaxCellSize_35(); }

  private native void ShallowCopy_36(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_36(id0); }

  private native void DeepCopy_37(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_37(id0); }

  private native void GetPointsOnFace_38(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3);
  public void GetPointsOnFace(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3)
    { GetPointsOnFace_38(id0,id1,id2,id3); }

  private native void GetPointsOnParentFaces_39(int id0[],int id1,vtkHyperOctreeCursor id2,vtkHyperOctreePointsGrabber id3);
  public void GetPointsOnParentFaces(int id0[],int id1,vtkHyperOctreeCursor id2,vtkHyperOctreePointsGrabber id3)
    { GetPointsOnParentFaces_39(id0,id1,id2,id3); }

  private native void GetPointsOnEdge_40(vtkHyperOctreeCursor id0,int id1,int id2,int id3,int id4,vtkHyperOctreePointsGrabber id5);
  public void GetPointsOnEdge(vtkHyperOctreeCursor id0,int id1,int id2,int id3,int id4,vtkHyperOctreePointsGrabber id5)
    { GetPointsOnEdge_40(id0,id1,id2,id3,id4,id5); }

  private native void GetPointsOnParentEdge_41(vtkHyperOctreeCursor id0,int id1,int id2,int id3,int id4,vtkHyperOctreePointsGrabber id5);
  public void GetPointsOnParentEdge(vtkHyperOctreeCursor id0,int id1,int id2,int id3,int id4,vtkHyperOctreePointsGrabber id5)
    { GetPointsOnParentEdge_41(id0,id1,id2,id3,id4,id5); }

  private native void GetPointsOnEdge2D_42(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3);
  public void GetPointsOnEdge2D(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3)
    { GetPointsOnEdge2D_42(id0,id1,id2,id3); }

  private native void GetPointsOnParentEdge2D_43(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3);
  public void GetPointsOnParentEdge2D(vtkHyperOctreeCursor id0,int id1,int id2,vtkHyperOctreePointsGrabber id3)
    { GetPointsOnParentEdge2D_43(id0,id1,id2,id3); }

  private native long GetLeafData_44();
  public vtkDataSetAttributes GetLeafData() {
    long temp = GetLeafData_44();

    if (temp == 0) return null;
    return (vtkDataSetAttributes)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDualGridFlag_45(int id0);
  public void SetDualGridFlag(int id0)
    { SetDualGridFlag_45(id0); }

  private native int GetDualGridFlag_46();
  public int GetDualGridFlag()
    { return GetDualGridFlag_46(); }

  private native int GetActualMemorySize_47();
  public int GetActualMemorySize()
    { return GetActualMemorySize_47(); }

  private native long GetData_48(vtkInformation id0);
  public vtkHyperOctree GetData(vtkInformation id0) {
    long temp = GetData_48(id0);

    if (temp == 0) return null;
    return (vtkHyperOctree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_49(vtkInformationVector id0,int id1);
  public vtkHyperOctree GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_49(id0,id1);

    if (temp == 0) return null;
    return (vtkHyperOctree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCell_50(int id0,int id1,int id2);
  public vtkCell GetCell(int id0,int id1,int id2) {
    long temp = GetCell_50(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkHyperOctree() { super(); }

  public vtkHyperOctree(long id) { super(id); }
  public native long   VTKInit();

}
